package com.qmth.distributed.print.business.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.qmth.distributed.print.business.bean.result.PrintPlanResult;
import com.qmth.distributed.print.business.entity.ExamDetail;
import com.qmth.distributed.print.business.entity.ExamPrintPlan;
import com.qmth.distributed.print.business.enums.PrintPlanStatusEnum;
import com.qmth.distributed.print.business.mapper.ExamPrintPlanMapper;
import com.qmth.distributed.print.business.service.ExamDetailService;
import com.qmth.distributed.print.business.service.ExamPrintPlanService;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 印刷计划管理 服务实现类
 * </p>
 *
 * @author xf
 * @since 2021-03-23
 */
@Service
public class ExamPrintPlanServiceImpl extends ServiceImpl<ExamPrintPlanMapper, ExamPrintPlan> implements ExamPrintPlanService {
    @Resource
    private ExamPrintPlanMapper examPrintPlanMapper;
    @Resource
    private ExamDetailService examDetailService;

    @Transactional(rollbackFor = Exception.class)
    @Override
    public IPage<PrintPlanResult> printPlanPage(Long schoolId, String name, PrintPlanStatusEnum status, Long startTime, Long endTime, int pageNumber, int pageSize) {
        IPage<PrintPlanResult> page = examPrintPlanMapper.findPrintPlanPage(new Page<>(pageNumber, pageSize), schoolId, name, status, startTime, endTime);
        List<PrintPlanResult> list = page.getRecords();
        for (PrintPlanResult printPlanResult : list) {
            List<Map> variableContent = JSONObject.parseArray(printPlanResult.getVariableContentTemp(),Map.class);
            List<Map> ordinaryContent = JSONObject.parseArray(printPlanResult.getOrdinaryContentTemp(),Map.class);
            printPlanResult.setVariableContent(variableContent);
            printPlanResult.setOrdinaryContent(ordinaryContent);

            double totalSubjects = examDetailService.calculateTotalSubjects(printPlanResult.getId());
            double totalPackages = examDetailService.calculateTotalPackages(printPlanResult.getId());
            printPlanResult.setTotalSubjects((int) totalSubjects);
            // TODO: 2021/4/4 总卷袋数的计算好像有问题 
            printPlanResult.setTotalPackages((int) totalPackages);
        }
        return page;
    }
}
